summaryrefslogtreecommitdiffstats
path: root/kmail/newfolderdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/newfolderdialog.cpp')
-rw-r--r--kmail/newfolderdialog.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/newfolderdialog.cpp b/kmail/newfolderdialog.cpp
index acd5b332..6d1de7cd 100644
--- a/kmail/newfolderdialog.cpp
+++ b/kmail/newfolderdialog.cpp
@@ -16,11 +16,11 @@
**
** In addition, as a special exception, the copyright holders give
** permission to link the code of this program with any edition of
-** the Qt library by Trolltech AS, Norway (or with modified versions
-** of Qt that use the same license as Qt), and distribute linked
+** the TQt library by Trolltech AS, Norway (or with modified versions
+** of TQt that use the same license as TQt), and distribute linked
** combinations including the two. You must obey the GNU General
** Public License in all respects for all of the code used other than
-** Qt. If you modify this file, you may extend this exception to
+** TQt. If you modify this file, you may extend this exception to
** your version of the file, but you are not obligated to do so. If
** you do not wish to do so, delete this exception statement from
** your version.
@@ -55,8 +55,8 @@
using namespace KMail;
-NewFolderDialog::NewFolderDialog( TQWidget* parent, KMFolder *folder )
- : KDialogBase( parent, "new_folder_dialog", false, i18n( "New Folder" ),
+NewFolderDialog::NewFolderDialog( TQWidget* tqparent, KMFolder *folder )
+ : KDialogBase( tqparent, "new_folder_dialog", false, i18n( "New Folder" ),
KDialogBase::Ok|KDialogBase::Cancel,
KDialogBase::Ok, true ),
mFormatComboBox( 0 ),
@@ -201,16 +201,16 @@ void NewFolderDialog::slotOk()
return;
}
// default parent is Top Level local folders
KMFolderDir * selectedFolderDir = &(kmkernel->folderMgr()->dir());
// we got a parent, let's use that
if ( mFolder )
selectedFolderDir = mFolder->createChildFolder();
// check if the folder already exists
if( selectedFolderDir->hasNamedFolder( fldName )
&& ( !( mFolder
- && ( selectedFolderDir == mFolder->parent() )
+ && ( selectedFolderDir == mFolder->tqparent() )
&& ( mFolder->storage()->name() == fldName ) ) ) )
{
const TQString message = i18n( "<qt>Failed to create folder <b>%1</b>, folder already exists.</qt>" ).arg(fldName);
@@ -201,16 +201,16 @@ void NewFolderDialog::slotOk()
return;
}
- // default parent is Top Level local folders
+ // default tqparent is Top Level local folders
KMFolderDir * selectedFolderDir = &(kmkernel->folderMgr()->dir());
@@ -201,16 +201,16 @@ void NewFolderDialog::slotOk()
KMFolderDir * selectedFolderDir = &(kmkernel->folderMgr()->dir());
- // we got a parent, let's use that
+ // we got a tqparent, let's use that
if ( mFolder )
selectedFolderDir = mFolder->createChildFolder();